==> haskell-say-0.1.0.1-20-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-say.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 say
version:              0.1.0.1
visibility:           public
id:                   say-0.1.0.1-9r7ZNwjzuzaHog7yzUBusz
key:                  say-0.1.0.1-9r7ZNwjzuzaHog7yzUBusz
license:              MIT
copyright:            2016-2018 FP Complete
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/fpco/say#readme
synopsis:             Send textual messages to a Handle in a thread-friendly way
description:
    Please see the README and documentation at <https://www.stackage.org/package/say>

category:             Text
abi:                  c72350266459d26ec3088dbeafc1a1ad
exposed:              True
exposed-modules:      Say
hidden-modules:       Paths_say
import-dirs:          /usr/lib/ghc-8.10.1/site-local/say-0.1.0.1
library-dirs:         /usr/lib/ghc-8.10.1/site-local/say-0.1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/say-0.1.0.1
hs-libraries:         HSsay-0.1.0.1-9r7ZNwjzuzaHog7yzUBusz
depends:
    base-4.14.0.0 bytestring-0.10.10.0 text-1.2.3.2
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-say/html/say.haddock
haddock-html:         /usr/share/doc/haskell-say/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-say-0.1.0.1-22-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-say.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 say
version:              0.1.0.1
visibility:           public
id:                   say-0.1.0.1-Hal9ep2ue2G4TwbIx1ERjO
key:                  say-0.1.0.1-Hal9ep2ue2G4TwbIx1ERjO
license:              MIT
copyright:            2016-2018 FP Complete
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/fpco/say#readme
synopsis:             Send textual messages to a Handle in a thread-friendly way
description:
    Please see the README and documentation at <https://www.stackage.org/package/say>

category:             Text
abi:                  b1021fa922a1931c1f900b1de8e5acb1
exposed:              True
exposed-modules:      Say
hidden-modules:       Paths_say
import-dirs:          /usr/lib/ghc-8.10.1/site-local/say-0.1.0.1
library-dirs:         /usr/lib/ghc-8.10.1/site-local/say-0.1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.1/say-0.1.0.1
hs-libraries:         HSsay-0.1.0.1-Hal9ep2ue2G4TwbIx1ERjO
depends:
    base-4.14.0.0 bytestring-0.10.10.0 text-1.2.3.2
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-say/html/say.haddock
haddock-html:         /usr/share/doc/haskell-say/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
